@@ -32,15 +32,21 @@ class Course : public CourseBase
     Q_OBJECT
     Q_PROPERTY(DataIndexCourse* associatedDataIndexCourse READ associatedDataIndexCourse WRITE setAssociatedDataIndexCourse NOTIFY associatedDataIndexCourseChanged)
     Q_PROPERTY(int lessonCount READ lessonCount NOTIFY lessonCountChanged)
-    Q_PROPERTY(bool doSyncLessonCharacters READ doSyncLessonCharacters WRITE setDoSyncLessonCharacters NOTIFY doSyncLessonCharactersChanged)
+    Q_PROPERTY(Kind kind READ kind WRITE setKind NOTIFY kindChanged)
 
 public:
+    enum Kind {
+        SequentialCourse,
+        LessonCollection
+    };
+    Q_ENUM(Kind)
+
     explicit Course(QObject *parent = 0);
     DataIndexCourse* associatedDataIndexCourse() const;
     void setAssociatedDataIndexCourse(DataIndexCourse* dataIndexCourse);
     int lessonCount() const;
-    bool doSyncLessonCharacters() const;
-    void setDoSyncLessonCharacters(bool doSync);
+    Kind kind() const;
+    void setKind(Kind kind);
     void setId(const QString& id);
     void setTitle(const QString& title);
     void setDescription(const QString& description);
@@ -49,13 +55,14 @@ public:
     Q_INVOKABLE void addLesson(Lesson* lesson);
     Q_INVOKABLE void insertLesson(int index, Lesson* lesson);
     Q_INVOKABLE void removeLesson(int index);
+    Q_INVOKABLE int indexOfLesson(Lesson* lesson);
     Q_INVOKABLE void clearLessons();
     Q_INVOKABLE void copyFrom(Course* source);
 
 signals:
     void associatedDataIndexCourseChanged();
     void lessonCountChanged();
-    void doSyncLessonCharactersChanged();
+    void kindChanged();
     void lessonAboutToBeAdded(Lesson* lesson, int index);
     void lessonAdded();
     void lessonsAboutToBeRemoved(int first, int last);
@@ -67,7 +74,7 @@ private slots:
 private:
     Q_DISABLE_COPY(Course)
     DataIndexCourse* m_associatedDataIndexCourse;
-    bool m_doSyncLessonCharacters;
+    Kind m_kind;
     QList<Lesson*> m_lessons;
     QSignalMapper* m_signalMapper;
 };
