@@ -26,12 +26,12 @@ class CharactersViewDelegate : public QStyledItemDelegate
 {
     Q_OBJECT
 public:
-    explicit CharactersViewDelegate(QObject* parent = 0);
+    explicit CharactersViewDelegate(QObject* parent = nullptr);
     KeyboardLayout* keyboardLayout() const;
     void setKeyboardLayout(KeyboardLayout* keyboardLayout);
-    QWidget* createEditor(QWidget* parent, const QStyleOptionViewItem& option, const QModelIndex& index) const;
-    void setEditorData(QWidget* editor, const QModelIndex& index) const;
-    void setModelData(QWidget *editor, QAbstractItemModel* model, const QModelIndex& index) const;
+    QWidget* createEditor(QWidget* parent, const QStyleOptionViewItem& option, const QModelIndex& index) const  override;
+    void setEditorData(QWidget* editor, const QModelIndex& index) const override;
+    void setModelData(QWidget *editor, QAbstractItemModel* model, const QModelIndex& index) const override;
 private:
     KeyboardLayout* m_keyboardLayout;
 };
